document.addEventListener('DOMContentLoaded', function() {
  var rows = document.querySelectorAll('tr');
  rows.forEach(function(row) {
    var rankCell = row.querySelector('td span.rank');
    if (rankCell) {
      var freqCell = row.querySelector('td span.freq');
      var headCell = row.querySelector('td span.headword');
      
      // 如果 '【TOP' 已经存在于 freqCell，跳过该单元格，避免重复添加
      if (freqCell.textContent.includes('【TOP')) {
        return;  // 跳过这一行，避免重复添加
      }

      if (headCell.textContent.includes('【TOP')) {
        return;  // 跳过这一行，避免重复添加
      }
      
      // 获取排名值
      var rankValue = rankCell.textContent.trim();
      
      // 计算排名并将其转换为 [1k ~ 98k] 的格式
      var calculatedValue = Math.round(98185 * (1 - rankValue));

      // 如果排名在 0 到 999 之间，直接显示排名；否则使用 k 表示法
      var displayedValue;
      if (calculatedValue < 1000) {
        displayedValue = calculatedValue;  // 直接显示排名
      } else {
        displayedValue = Math.floor(calculatedValue / 1000 + 1) + 'k';  // 转换为 k 表示法
      }

      // 创建一个 div 容器来包含 headCell 的原始文本内容
      var headwordContainer = document.createElement('div');
      headwordContainer.className = 'headword-container';
      headwordContainer.textContent = headCell.textContent;  // 将 headCell 的文本放入 div 容器中
      // 清空 headCell 的原始内容
      headCell.textContent = '';
      // 将 headwordContainer 添加到 headCell 内
      headCell.appendChild(headwordContainer);

      // 创建频率容器并设置排名文本
      var freqContainer = document.createElement('div');
      freqContainer.className = 'freq-container';
      freqContainer.textContent = '【TOP ' + displayedValue + '】';

      headCell.appendChild(freqContainer);
    }
  });
});